@@ -54,7 +54,7 @@ class CCI(object):
 class Cloud_CCI(CCI, AProduct):
 
     def get_file_signature(self):
-        return [r'..*ESACCI.*CLOUD.*']
+        return [r'.*ESACCI.*CLOUD.*']
 
     def _fix_time(self, coord):
         coord.convert_julian_to_std_time()
